==> haskell-commonmark-extensions-0.2.5.2-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-extensions
version:              0.2.5.2
visibility:           public
id:                   commonmark-extensions-0.2.5.2-7EoRqoTRMch2czHoHN9hB1
key:                  commonmark-extensions-0.2.5.2-7EoRqoTRMch2czHoHN9hB1
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  1a555608c0b7907207aa9ab9c574a6f7
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.2.8/site-local/commonmark-extensions-0.2.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/commonmark-extensions-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.2-7EoRqoTRMch2czHoHN9hB1
depends:
    base-4.16.4.0 commonmark-0.2.4.1-4rKljUoDDcl60Y7suHMYSv
    containers-0.6.5.1 emojis-0.1.3-7lp6bSa8ElkLZwS3L5NWjG
    filepath-1.4.2.2 network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    parsec-3.1.15.0 text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.5.3-24.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.3
visibility:           public
id:                   commonmark-extensions-0.2.5.3-FzoY4a2IuzQH6wPwct89Cv
key:                  commonmark-extensions-0.2.5.3-FzoY4a2IuzQH6wPwct89Cv
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  db58c59cbe3981214c713bf5c601990f
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.3-FzoY4a2IuzQH6wPwct89Cv
depends:
    base-4.17.2.1 commonmark-0.2.5.1-5pjTNeCfm206J6ShNYlbAW
    containers-0.6.7 emojis-0.1.4.1-FZxZVzFxHM1FXNM5saKrpG
    filepath-1.4.2.2 network-uri-2.6.4.2-6a0tnrWM371Ip5S0wD8Wxe
    parsec-3.1.16.1 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
